Argument

Enum Argument 

pub enum Argument {
    Gas,
    Input(u16),
    Result(u16),
    NestedResult(u16, u16),
}
An argument to a programmable transaction command

BCS

The BCS serialized form for this type is defined by the following ABNF:

argument    =  argument-gas
            =/ argument-input
            =/ argument-result
            =/ argument-nested-result

argument-gas            = %x00
argument-input          = %x01 u16
argument-result         = %x02 u16
argument-nested-result  = %x03 u16 u16

Variants



Gas

The gas coin. The gas coin can only be used by-ref, except for with TransferObjects, which can use it by-value.



Input(u16)

One of the input objects or primitive values (from ProgrammableTransaction inputs)



Result(u16)

The result of another command (from ProgrammableTransaction commands)



NestedResult(u16, u16)

Like a Result but it accesses a nested result. Currently, the only usage of this is to access a value from a Move call with multiple return values.

Implementations

Source

impl Argument

pub fn nested(&self, ix: u16) -> Option<Argument>

Turn a Result into a NestedResult. If the argument is not a Result, returns None.