Digest

Struct Digest 

pub struct Digest(/* private fields */);
A 32-byte Blake2b256 hash output.

BCS

A Digest’s BCS serialized form is defined by the following:

digest = %x20 32OCTET

Due to historical reasons, even though a Digest has a fixed-length of 32, Sui’s binary representation of a Digest is prefixed with its length meaning its serialized binary form (in bcs) is 33 bytes long vs a more compact 32 bytes.

Implementations

Source

impl Digest

pub const LENGTH: usize = 32

A constant representing the length of a digest in bytes.

pub const ZERO: Self

A constant representing a zero digest.

pub const fn new(digest: [u8; 32]) -> Self

Generates a new digest from the provided 32 byte array containing u8 values.

pub fn generate<R>(rng: R) -> Self
where R: RngCore + CryptoRng,

Available on crate feature rand only.

Generates a new digest from the provided random number generator.

pub const fn inner(&self) -> &[u8; 32]

Returns a slice to the inner array representation of this digest.

pub const fn into_inner(self) -> [u8; 32]

Returns the inner array representation of this digest.

pub const fn as_bytes(&self) -> &[u8]

Returns a slice of bytes representing the digest.

pub fn from_base58<T: AsRef<[u8]>>(base58: T) -> Result<Self, DigestParseError>

Decodes a digest from a Base58 encoded string.

pub const fn from_static(base58: &'static str) -> Self

Decodes a digest from a Base58 encoded &’static str.

Similar to from_base58 except any errors are unwrapped, turning them into panics.

pub fn to_base58(&self) -> String

Returns a Base58 encoded string representation of this digest.

pub fn from_bytes<T: AsRef<[u8]>>(bytes: T) -> Result<Self, DigestParseError>

Generates a digest from bytes.